==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/ecs_cluster/EcsClusterConfiguration.java <==
package com.hashicorp.cdktf.providers.aws.ecs_cluster;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:53.766Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.ecsCluster.EcsClusterConfiguration")
@software.amazon.jsii.Jsii.Proxy(EcsClusterConfiguration.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface EcsClusterConfiguration extends software.amazon.jsii.JsiiSerializable {

    /**
     * execute_command_configuration block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#execute_command_configuration EcsCluster#execute_command_configuration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.ecs_cluster.EcsClusterConfigurationExecuteCommandConfiguration getExecuteCommandConfiguration() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link EcsClusterConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link EcsClusterConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<EcsClusterConfiguration> {
        com.hashicorp.cdktf.providers.aws.ecs_cluster.EcsClusterConfigurationExecuteCommandConfiguration executeCommandConfiguration;

        /**
         * Sets the value of {@link EcsClusterConfiguration#getExecuteCommandConfiguration}
         * @param executeCommandConfiguration execute_command_configuration block.
         *                                    Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/ecs_cluster#execute_command_configuration EcsCluster#execute_command_configuration}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder executeCommandConfiguration(com.hashicorp.cdktf.providers.aws.ecs_cluster.EcsClusterConfigurationExecuteCommandConfiguration executeCommandConfiguration) {
            this.executeCommandConfiguration = executeCommandConfiguration;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EcsClusterConfiguration}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public EcsClusterConfiguration build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link EcsClusterConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements EcsClusterConfiguration {
        private final com.hashicorp.cdktf.providers.aws.ecs_cluster.EcsClusterConfigurationExecuteCommandConfiguration executeCommandConfiguration;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.executeCommandConfiguration = software.amazon.jsii.Kernel.get(this, "executeCommandConfiguration", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.ecs_cluster.EcsClusterConfigurationExecuteCommandConfiguration.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.executeCommandConfiguration = builder.executeCommandConfiguration;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.ecs_cluster.EcsClusterConfigurationExecuteCommandConfiguration getExecuteCommandConfiguration() {
            return this.executeCommandConfiguration;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getExecuteCommandConfiguration() != null) {
                data.set("executeCommandConfiguration", om.valueToTree(this.getExecuteCommandConfiguration()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.ecsCluster.EcsClusterConfiguration"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            EcsClusterConfiguration.Jsii$Proxy that = (EcsClusterConfiguration.Jsii$Proxy) o;

            return this.executeCommandConfiguration != null ? this.executeCommandConfiguration.equals(that.executeCommandConfiguration) : that.executeCommandConfiguration == null;
        }

        @Override
        public final int hashCode() {
            int result = this.executeCommandConfiguration != null ? this.executeCommandConfiguration.hashCode() : 0;
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/ecs_cluster/EcsClusterConfiguration.java <==
package com.hashicorp.cdktf.providers.aws.ecs_cluster;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:09.633Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.ecsCluster.EcsClusterConfiguration")
@software.amazon.jsii.Jsii.Proxy(EcsClusterConfiguration.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface EcsClusterConfiguration extends software.amazon.jsii.JsiiSerializable {

    /**
     * execute_command_configuration block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/ecs_cluster#execute_command_configuration EcsCluster#execute_command_configuration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.ecs_cluster.EcsClusterConfigurationExecuteCommandConfiguration getExecuteCommandConfiguration() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link EcsClusterConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link EcsClusterConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<EcsClusterConfiguration> {
        com.hashicorp.cdktf.providers.aws.ecs_cluster.EcsClusterConfigurationExecuteCommandConfiguration executeCommandConfiguration;

        /**
         * Sets the value of {@link EcsClusterConfiguration#getExecuteCommandConfiguration}
         * @param executeCommandConfiguration execute_command_configuration block.
         *                                    Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/ecs_cluster#execute_command_configuration EcsCluster#execute_command_configuration}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder executeCommandConfiguration(com.hashicorp.cdktf.providers.aws.ecs_cluster.EcsClusterConfigurationExecuteCommandConfiguration executeCommandConfiguration) {
            this.executeCommandConfiguration = executeCommandConfiguration;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link EcsClusterConfiguration}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public EcsClusterConfiguration build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link EcsClusterConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements EcsClusterConfiguration {
        private final com.hashicorp.cdktf.providers.aws.ecs_cluster.EcsClusterConfigurationExecuteCommandConfiguration executeCommandConfiguration;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.executeCommandConfiguration = software.amazon.jsii.Kernel.get(this, "executeCommandConfiguration", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.ecs_cluster.EcsClusterConfigurationExecuteCommandConfiguration.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.executeCommandConfiguration = builder.executeCommandConfiguration;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.ecs_cluster.EcsClusterConfigurationExecuteCommandConfiguration getExecuteCommandConfiguration() {
            return this.executeCommandConfiguration;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getExecuteCommandConfiguration() != null) {
                data.set("executeCommandConfiguration", om.valueToTree(this.getExecuteCommandConfiguration()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.ecsCluster.EcsClusterConfiguration"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            EcsClusterConfiguration.Jsii$Proxy that = (EcsClusterConfiguration.Jsii$Proxy) o;

            return this.executeCommandConfiguration != null ? this.executeCommandConfiguration.equals(that.executeCommandConfiguration) : that.executeCommandConfiguration == null;
        }

        @Override
        public final int hashCode() {
            int result = this.executeCommandConfiguration != null ? this.executeCommandConfiguration.hashCode() : 0;
            return result;
        }
    }
}
